@@ -4,7 +4,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -38,6 +38,7 @@ __docformat__ = 'restructuredtext'
 
 import sys
 import time
+import copy
 import types
 import ctypes
 import weakref
@@ -1773,25 +1774,33 @@ class Macro(Logger):
     
     @mAPI
     def getViewOption(self, name):
-        return self._getViewOptions()[name]
-    
+        return self._getViewOption(name)
+
     @mAPI
     def getViewOptions(self):
-        return self._getViewOptions()
+        vo = self._getViewOptions()
+        # ensure that all view options known by sardana are present, in case
+        # there were missing ones, update _ViewOptions dictionary after 
+        # initializing missing options with the default values
+        ivo = copy.deepcopy(vo)
+        ViewOption.init_options(ivo)
+        if vo != ivo:
+            self.setEnv('_ViewOptions', vo)
+        return ivo
 
     @mAPI
     def setViewOption(self, name, value):
         vo = self._getViewOptions()
         vo[name] = value
         self.setEnv('_ViewOptions', vo)
-    
+
     @mAPI
     def resetViewOption(self, name):
         vo = self._getViewOptions()
         ViewOption.reset_option(vo, name)
         self.setEnv('_ViewOptions', vo)
         return vo.get(name)
-    
+
     #@}
 
     ## @name Unofficial Macro API
@@ -1803,16 +1812,27 @@ class Macro(Logger):
     #  consider informing the MacroServer developer so he may expose this in a
     #  safe way.
     #@{
-    
     def _getViewOptions(self):
+        '''Gets _ViewOption dictionary. If it is not defined in the environment,
+        sets it with the default values dictionary and returns it.
+        '''
         try:
             vo = self.getEnv('_ViewOptions')
         except UnknownEnv:
-            import msoptions
             vo = ViewOption.init_options(dict())
             self.setEnv('_ViewOptions', vo)
         return vo
 
+    def _getViewOption(self, name):
+        '''Gets _ViewOption of a given name. If it is not defined in 
+        the environment, sets it to a default value and returns it.
+        '''
+        view_options = self._getViewOptions()
+        if not view_options.has_key(name):
+            ViewOption.reset_option(view_options, name)
+            self.setEnv('_ViewOptions', view_options)
+        return view_options[name]
+
     def _input(self, msg, *args, **kwargs):
         """**Unofficial Macro API**.
         If args is present, it is written to standard output without a trailing
