@@ -2,7 +2,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -298,7 +298,7 @@ class dNscan(aNscan):
 
     def _prepare(self, motorlist, startlist, endlist, scan_length, integ_time, mode=StepMode, **opts):
         self._motion=self.getMotion( [ m.getName() for m in motorlist] )
-        self.originalPositions = numpy.array(self._motion.readPosition())
+        self.originalPositions = numpy.array(self._motion.readPosition(force=True))
         starts = numpy.array(startlist, dtype='d') + self.originalPositions
         finals = numpy.array(endlist, dtype='d') + self.originalPositions
         aNscan._prepare(self, motorlist, starts, finals, scan_length, integ_time, mode=mode, **opts)
@@ -670,6 +670,58 @@ class mesh(Macro,Hookable):
     def data(self):
         return self._gScan.data
 
+class dmesh(mesh): 
+    '''2d relative grid scan.
+    The relative mesh scan traces out a grid using motor1 and motor2.
+    If first motor is at the position X before the scan begins, it will
+    be scanned from X+m1_start_pos to X+m1_final_pos using the specified
+    m1_nr_interv number of intervals. If the second motor is
+    at the position Y before the scan begins, it will be scanned
+    from Y+m2_start_pos to Y+m2_final_pos using the specified m2_nr_interv
+    number of intervals.
+    Each point is counted for the integ_time seconds (or monitor counts,
+    if integ_time is negative).
+    The scan of motor1 is done at each point scanned by motor2. That is, the
+    first motor scan is nested within the second motor scan.
+    Upon scan completion, it returns the motors to their original positions.
+    '''
+
+    hints = copy.deepcopy(mesh.hints)
+    hints['scan'] = 'dmesh'
+
+    env = copy.deepcopy(mesh.env)
+ 
+    param_def = [
+       ['motor1',      Type.Moveable,   None, 'First motor to move'],
+       ['m1_start_pos',Type.Float,   None, 'Scan start position for first motor'],
+       ['m1_final_pos',Type.Float,   None, 'Scan final position for first motor'],
+       ['m1_nr_interv',Type.Integer, None, 'Number of scan intervals'],
+       ['motor2',      Type.Moveable,   None, 'Second motor to move'],
+       ['m2_start_pos',Type.Float,   None, 'Scan start position for second motor'],
+       ['m2_final_pos',Type.Float,   None, 'Scan final position for second motor'],
+       ['m2_nr_interv',Type.Integer, None, 'Number of scan intervals'],
+       ['integ_time',  Type.Float,   None, 'Integration time'],
+       ['bidirectional',   Type.Boolean, False, 'Save time by scanning s-shaped']
+    ]
+
+    def prepare(self, m1, m1_start_pos, m1_final_pos, m1_nr_interv,
+                m2, m2_start_pos, m2_final_pos, m2_nr_interv, integ_time,
+                bidirectional, **opts):
+        self._motion=self.getMotion( [m1,m2] )
+        self.originalPositions = numpy.array(self._motion.readPosition(force=True))
+        start1 = self.originalPositions[0] +  m1_start_pos
+        start2 =  self.originalPositions[1] +  m2_start_pos
+        final1 = self.originalPositions[0] +  m1_final_pos
+        final2 =  self.originalPositions[1] +  m2_final_pos
+        mesh.prepare(self, m1, start1, final1, m1_nr_interv,
+                m2, start2, final2, m2_nr_interv, integ_time,
+                bidirectional, **opts)
+
+    def do_restore(self):
+        self.info("Returning to start positions...")
+        self._motion.move(self.originalPositions)
+
+
 class fscan(Macro,Hookable):
     '''N-dimensional scan along user defined paths.
     The motion path for each motor is defined through the evaluation of a
@@ -1094,8 +1146,12 @@ class meshc(Macro,Hookable):
         self.nr_waypoints = m2_nr_interv + 1
         
         self.name=opts.get('name','meshc')
-        
-        moveables=self.motors
+
+        moveables = []
+        for m, start, final in zip(self.motors, self.starts, self.finals):
+            moveables.append(MoveableDesc(moveable=m, min_value=min(start,final), max_value=max(start,final)))
+        moveables[0].is_reference = True
+
         env=opts.get('env',{})
         constrains=[getCallable(cns) for cns in opts.get('constrains',[UNCONSTRAINED])]
         extrainfodesc = opts.get('extrainfodesc',[])
@@ -1104,7 +1160,7 @@ class meshc(Macro,Hookable):
         #self.pre_scan_hooks = self.getHooks('pre-scan')
         #self.post_scan_hooks = self.getHooks('post-scan'
 
-        self._gScan = CScan(self, self._waypoint_generator, self._period_generator, moveables, env, constrains, extrainfodesc)
+        self._gScan = CSScan(self, self._waypoint_generator, self._period_generator, moveables, env, constrains, extrainfodesc)
         self._gScan.frozen_motors = [m2]
         
     def _waypoint_generator(self):
@@ -1154,7 +1210,59 @@ class meshc(Macro,Hookable):
     @property
     def data(self):
         return self._gScan.data
-    
+
+
+class dmeshc(meshc): 
+    '''2d relative continuous grid scan.
+    The relative mesh scan traces out a grid using motor1 and motor2.
+    If first motor is at the position X before the scan begins, it will
+    be continuously scanned from X+m1_start_pos to X+m1_final_pos.
+    If the second motor is at the position Y before the scan begins,
+    it will be discrete scanned from Y+m2_start_pos to Y+m2_final_pos
+    using the specified m2_nr_interv number of intervals.
+    The scan considers the accel. and decel. times of the motor1, so the
+    counts (for the integ_time seconds or monitor counts,
+    if integ_time is negative) are executed while motor1 is moving
+    with the constant velocity.
+    Upon scan completion, it returns the motors to their original positions.
+    '''
+
+    hints = copy.deepcopy(meshc.hints)
+    hints['scan'] = 'dmeshc'
+
+    env = copy.deepcopy(meshc.env)
+
+    param_def = [
+       ['motor1',        Type.Moveable, None, 'First motor to move'],
+       ['m1_start_pos',  Type.Float,    None, 'Scan start position for first motor'],
+       ['m1_final_pos',  Type.Float,    None, 'Scan final position for first motor'],
+       ['slow_down',     Type.Float,    None, 'global scan slow down factor (0, 1]'],
+       ['motor2',        Type.Moveable, None, 'Second motor to move'],
+       ['m2_start_pos',  Type.Float,    None, 'Scan start position for second motor'],
+       ['m2_final_pos',  Type.Float,    None, 'Scan final position for second motor'],
+       ['m2_nr_interv',  Type.Integer,  None, 'Number of scan intervals'],
+       ['integ_time',    Type.Float,    None, 'Integration time'],
+       ['bidirectional', Type.Boolean,  False, 'Save time by scanning s-shaped']
+    ]
+
+    def prepare(self, m1, m1_start_pos, m1_final_pos, slow_down,
+                m2, m2_start_pos, m2_final_pos, m2_nr_interv, integ_time,
+                bidirectional, **opts):
+        self._motion=self.getMotion( [m1,m2] )
+        self.originalPositions = numpy.array(self._motion.readPosition(force=True))
+        start1 = self.originalPositions[0] +  m1_start_pos
+        start2 =  self.originalPositions[1] +  m2_start_pos
+        final1 = self.originalPositions[0] +  m1_final_pos
+        final2 =  self.originalPositions[1] +  m2_final_pos
+        meshc.prepare(self, m1, start1, final1, slow_down,
+                m2, start2, final2, m2_nr_interv, integ_time,
+                bidirectional, **opts)
+
+    def do_restore(self):
+        self.info("Returning to start positions...")
+        self._motion.move(self.originalPositions)
+
+
 class ascanct(aNscan, Macro):
     '''Continuous scan controlled by hardware trigger signals. A sequence of 
     trigger pulses is programmed by time. The scan active time is calculated from
