@@ -4,7 +4,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -42,11 +42,18 @@ class ViewOption(object):
 
     _DEFAULT_VIEW_OPTIONS = {
         'ShowDial' : True,
+        'ShowCtrlAxis' : False,
+        'PosFormat': -1,
     }
 
     @classmethod
     def init_options(cls, d):
-        d.update(cls._DEFAULT_VIEW_OPTIONS)
+        '''Init missing options with the default values.
+        '''
+        diff = set(cls._DEFAULT_VIEW_OPTIONS).difference(d)
+        if len(diff) > 0:
+            for key in diff:
+                d[key] = cls._DEFAULT_VIEW_OPTIONS[key]
         return d
 
     @classmethod
@@ -54,6 +61,6 @@ class ViewOption(object):
         if name in cls._DEFAULT_VIEW_OPTIONS:
             d[name] = cls._DEFAULT_VIEW_OPTIONS[name]
         else:
-            del d[name]
+            del d[name]    
 
 
