@@ -4,7 +4,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -250,7 +250,7 @@ class GScan(Logger):
         except UnknownEnv:
             mnt_grps = macro.getObjs(".*", type_class=Type.MeasurementGroup)
             if len(mnt_grps) == 0:
-                ScanSetupError('No Measurement Group defined')
+                raise ScanSetupError('No Measurement Group defined')
             mnt_grp = mnt_grps[0]
             macro.info("ActiveMntGrp not defined. Using %s", mnt_grp)
             macro.setEnv('ActiveMntGrp', mnt_grp.getName())
@@ -395,7 +395,7 @@ class GScan(Logger):
             raise
         except Exception:
             macro.warning('ScanFile is not defined. This operation will not '
-                          'be stored persistently. Use "expconf" (or "senv ScanDir <scan '
+                          'be stored persistently. Use "expconf" (or "senv ScanFile <scan '
                           'file(s)>") to enable it')
             return ()
 
@@ -1003,6 +1003,12 @@ class CScan(GScan):
         self._moveables_trees, \
         physical_moveables_names, \
         self._physical_moveables = data_structures
+        # The physical motion object contains only physical motors - no pseudo
+        # motors (in case the pseudomotors are involved in the scan,
+        # it comprarises the underneath physical motors)
+        # This is due to the fact that the CTScan coordinates the
+        # pseudomotors' underneeth physical motors on on their constant
+        # velocity in contrary to the the CScan which do not coordinate them
         self._physical_motion = self.macro.getMotion(physical_moveables_names)
         
     def populate_moveables_data_structures(self, moveables):
@@ -1077,8 +1083,7 @@ class CScan(GScan):
         if restore_positions is not None:
             self._setFastMotions()
             self.macro.info("Correcting overshoot...")
-            self._physical_motion.move(restore_positions)
-            #self.motion.move(restore_positions)
+            self.motion.move(restore_positions)
         self.do_restore()
         self.motion_end_event.set()        
         self.motion_event.set()
@@ -2025,9 +2030,8 @@ class CTScan(CScan):
                 
                 for moveable, start, final in zip(moveables, starts, finals):
                     name = moveable.moveable.getName()
-                    step_size = abs((end - start) / nr_of_points)
-                    for point_nr, position in enumerate(np.arange(start, \
-                                                            final, step_size)):
+                    for point_nr, position in enumerate(np.linspace(start, \
+                                                        final, nr_of_points)):
                         positions_records[point_nr][name] = position    
                     
                 return positions_records
@@ -2046,8 +2050,24 @@ class CTScan(CScan):
         self.on_waypoints_end(positions)
         
     def on_waypoints_end(self, restore_positions=None):
+        """To be called by the waypoint thread to handle the end of waypoints
+        (either because no more waypoints or because a macro abort was
+        triggered)
+
+        .. todo:: Unify this method for all the continuous scans. Hint: use
+                  the motion property and return the _physical_motion member
+                  instead of _motion or in both cases: CSScan and CTScan
+                  coordinate the physical motors' velocit.
+        """
         self.macro.debug("on_waypoints_end() entering...")
-        CScan.on_waypoints_end(self, restore_positions=restore_positions)
+        self.set_all_waypoints_finished(True)
+        if restore_positions is not None:
+            self._setFastMotions()
+            self.macro.info("Correcting overshoot...")
+            self._physical_motion.move(restore_positions)
+        self.do_restore()
+        self.motion_end_event.set()        
+        self.motion_event.set()
         self.cleanup()
 
     def scan_loop(self):        
