@@ -4,7 +4,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -52,6 +52,9 @@ class SpockInputHandler(BaseInputHandler):
         if input_data is None:
             input_data = {}
         prompt = input_data.get('prompt')
+        if 'data_type' in input_data:
+            if input_data['data_type'] != 'String':
+                print("Accepted input:  %s" % input_data['data_type'])
         ret = dict(input=None, cancel=False)
         try:
             if prompt is None:
