@@ -4,7 +4,7 @@
 ##
 ## This file is part of Sardana
 ##
-## http://www.tango-controls.org/static/sardana/latest/doc/html/index.html
+## http://www.sardana-controls.org/
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -561,8 +561,8 @@ class BaseDoor(MacroServerDevice):
         input_type = input_data['type']
         if input_type == 'input':
             result = self._input_handler.input(input_data)
-            if result is '' and 'default_value' in input_data:
-                result = input_data['default_value']
+            if result['input'] is '' and 'default_value' in input_data:
+                result['input'] = input_data['default_value']
             result = CodecFactory().encode('json', ('', result))[1]
             self.write_attribute('Input', result)
         elif input_type == 'timeout':
@@ -1158,3 +1158,9 @@ def registerExtensions():
     factory = Factory('tango')
     factory.registerDeviceClass('MacroServer', BaseMacroServer)
     factory.registerDeviceClass('Door', BaseDoor)
+
+def unregisterExtensions():
+    """Registers the macroserver extensions in the :class:`taurus.core.tango.TangoFactory`"""
+    factory = Factory('tango')
+    factory.unregisterDeviceClass('MacroServer')
+    factory.unregisterDeviceClass('Door')
